@@ -1,9 +1,9 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
-** This file is part of the QtSvg module of the Qt Toolkit.
+** This file is part of the Qt SVG module of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
 ** Commercial License Usage
@@ -94,7 +94,7 @@ public:
         outputDevice = 0;
         resolution = 72;
 
-        attributes.document_title = QLatin1String("Qt Svg Document");
+        attributes.document_title = QLatin1String("Qt SVG Document");
         attributes.document_description = QLatin1String("Generated with Qt");
         attributes.font_family = QLatin1String("serif");
         attributes.font_size = QLatin1String("10pt");
@@ -540,7 +540,7 @@ public:
     The \l{SVG Generator Example} shows how the same painting commands can be used
     for painting a widget and writing an SVG file.
 
-    \sa QSvgRenderer, QSvgWidget, {Qt Svg C++ Classes}
+    \sa QSvgRenderer, QSvgWidget, {Qt SVG C++ Classes}
 */
 
 /*!
