@@ -52,8 +52,6 @@
 #include <QtCore/qscopedpointer.h>
 #include <QtSvg/qtsvgglobal.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 
@@ -106,7 +104,5 @@ private:
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif // QT_NO_SVGGENERATOR
 #endif // QSVGGENERATOR_H
