@@ -1,9 +1,9 @@
 /****************************************************************************
 **
-** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
-** This file is part of the QtSvg module of the Qt Toolkit.
+** This file is part of the Qt SVG module of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
 ** Commercial License Usage
@@ -54,9 +54,6 @@
 //
 
 #include "QtGui/qpainter.h"
-
-#ifndef QT_NO_SVG
-
 #include "QtGui/qpen.h"
 #include "QtGui/qbrush.h"
 #include "QtGui/qmatrix.h"
@@ -195,7 +192,7 @@ public:
 private:
     // color-render ing v 	v 	'auto' | 'optimizeSpeed' |
     //                                  'optimizeQuality' | 'inherit'
-    int m_colorRendering;
+    //int m_colorRendering;
 
     // shape-rendering v 	v 	'auto' | 'optimizeSpeed' | 'crispEdges' |
     //                                  'geometricPrecision' | 'inherit'
@@ -690,7 +687,7 @@ public:
 protected:
     void resolveMatrix(const QSvgNode *node);
 private:
-    qreal m_from, m_to, m_by;
+    qreal m_from, m_to;
     qreal m_totalRunningTime;
     TransformType m_type;
     Additive m_additive;
@@ -716,7 +713,7 @@ public:
     virtual void revert(QPainter *p, QSvgExtraStates &states);
     virtual Type type() const;
 private:
-    qreal m_from, m_to, m_by;
+    qreal m_from, m_to;
     qreal m_totalRunningTime;
     QList<QColor> m_colors;
     QBrush m_oldBrush;
@@ -822,5 +819,4 @@ public:
 
 QT_END_NAMESPACE
 
-#endif // QT_NO_SVG
 #endif // QSVGSTYLE_P_H
